@@ -37,7 +37,7 @@ class QModelIndex;
 namespace Analitza
 {
 class PlotItem;
-
+class Plotter2DPrivate;
 /**
  * \class Plotter2D
  * 
@@ -58,7 +58,7 @@ class ANALITZAPLOT_EXPORT Plotter2D
         struct GridInfo; // interval structure for carry current grid state information across interval methods
 
     public:
-        Plotter2D(const QSizeF& size);
+        explicit Plotter2D(const QSizeF& size);
         virtual ~Plotter2D();
 
         /** Sets whether we will draw the grid. */
@@ -101,7 +101,7 @@ class ANALITZAPLOT_EXPORT Plotter2D
         void updateFunctions(const QModelIndex & parent, int start, int end);
         
         void setModel(QAbstractItemModel* f);
-        QAbstractItemModel* model() const { return m_model; }
+        QAbstractItemModel* model() const;
         
         /** Sets the graph's viewport to @p v. */
         void setViewport(const QRectF& vp, bool repaint=true);
@@ -169,6 +169,7 @@ class ANALITZAPLOT_EXPORT Plotter2D
         
         QLineF toWidget(const QLineF &) const;
         void setPaintedSize(const QSize& size);
+        void setDevicePixelRatio(qreal dpr);
         void scaleViewport(qreal scale, const QPoint& center, bool repaint=true);
 
     private:
@@ -201,7 +202,8 @@ class ANALITZAPLOT_EXPORT Plotter2D
         QRectF viewport; // normalized viewport (with scale information), this one is the current viewport (used in currentViewport)
         QRectF userViewport; // raw viewport that user sets by setViewport, so we need to normalized userViewport into viewport to include scale and aspect radio information 
         QSizeF m_size;
-        QAbstractItemModel* m_model;
+
+        Plotter2DPrivate* const d;
         
         AngleMode m_angleMode;
         ScaleMode m_scaleMode;
