@@ -50,8 +50,8 @@ PlotsView2D::PlotsView2D(QWidget *parent)
     , mode(None)
     , m_framed(false)
     , m_readonly(false)
-    , m_selection(0)
-    , m_currentModel(0)
+    , m_selection(nullptr)
+    , m_currentModel(nullptr)
 {
     this->setFocusPolicy(Qt::ClickFocus);
     this->setCursor(Qt::CrossCursor);
@@ -279,8 +279,10 @@ void PlotsView2D::keyPressEvent(QKeyEvent * e)
 
 void PlotsView2D::resizeEvent(QResizeEvent * ev)
 {
-    buffer=QPixmap(ev->size());
-    setPaintedSize(ev->size());
+    if (ev->size() != buffer.size()) {
+        buffer = QPixmap(ev->size());
+        setPaintedSize(ev->size());
+    }
 }
 
 bool PlotsView2D::toImage(const QString &path, Format f)
